<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Models\User;
use App\Models\UserType;
use Validator;

class AuthController extends Controller
{
    public function __construct() {
        $this->middleware('auth:api', ['except' => ['login', 'register']]);
    }

    public function login(Request $request) {
        $loginValidator = Validator::make($request -> all(), [
            'phone' => 'required',
            'password' => 'required|string|min:6',
        ]);

        if ($loginValidator->fails()) {
            return response()->json($loginValidator->errors(), 422);
        }

        $user = User::wherePhone($request->input('phone'))->first();

        if ($user->type == UserType::ADMIN && $user->active) {
            return response()->json(['error' => 'Invalid user type, please user member account.'], 401);
        }

        if (! $token = auth()->attempt($loginValidator->validated())) {
            return response()->json(['error' => 'Unauthorized'], 401);
        }

        return $this->createNewToken($token);
    }

    public function register(Request $request) {
        $validator = Validator::make($request->all(), [
            'name' => 'required|string|between:2,100',
            'email' => 'string|email|max:100',
            'phone' => 'required|tel|max:10',
            'password' => 'required|string|confirmed|min:8',
            'type' => 'required|in:MEMBER,STAFF',
        ]);

        if($validator->fails()){
            return response()->json($validator->errors()->toJson(), 400);
        }

        $user = User::create(array_merge(
            $validator->validated(),
            ['password' => bcrypt($request->password)],
            ['active' => false],
        ));

        return response()->json([
            'message' => 'User successfully registered',
            'user' => $user
        ], 201);
    }

    public function logout() {
        auth()->logout();
        return response()->json(['message' => 'User successfully signed out']);
    }

    public function refresh() {
        return $this->createNewToken(auth()->refresh());
    }

    public function userProfile() {
        return response()->json(auth()->user());
    }

    protected function createNewToken($token){
        return response()->json([
            'access_token' => $token,
            'token_type' => 'bearer',
            'expires_in' => auth()->factory()->getTTL() * 60,
            'user' => auth()->user()
        ]);
    }
}
