<?php

namespace App\Http\Controllers;

use App\Models\Message;
use App\Models\MessageType;
use Illuminate\Http\Request;
use Illuminate\Http\RedirectResponse;
use Illuminate\Support\Facades\Auth;
use App\Models\User;
use App\Models\UserType;
use Illuminate\Support\Facades\Validator;

class LoginController extends Controller
{
    public function index() {
        if (!Auth::check()) {
            return view('auth.login');
        }

        return redirect()->intended('/');
    }

    public function authenticate(Request $request): RedirectResponse
    {
        $user = User::wherePhone($request->input('phone'))->first();

        if ($user && $user->type == UserType::ADMIN && $user->active) {
            $validator = Validator::make($request->all(), [
                'phone' => ['required', 'string', 'min:10'],
                'password' => ['required'],
            ]);

            if (!$validator->fails()) {
                $credentials = $validator->validated();

                if (Auth::attempt($credentials)) {
                    $request->session()->regenerate();
                    return redirect()->intended('/');
                }
            }
        }

        $messages = [
            new Message('The provided credentials are invalid.', MessageType::ERROR)
        ];

        return back()->with([
            'messages' => $messages,
        ])->onlyInput('phone');
    }

    public function logout (Request $request) {
        Auth::logout();
        $request->session()->invalidate();
        $request->session()->regenerateToken();
        return redirect()->route('login')
            ->withSuccess('You have logged out successfully!');;
    }
}
