<?php

namespace App\Models;

use App\Interfaces\Badged;
use App\Models\Badge;
use App\Traits\Enumifier;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;

enum LocationType: string implements Badged {
    use Enumifier;

    case DESK = 'DESK';
    case ROOM = 'ROOM';
    case STORAGE = 'STORAGE';

    public function badge(): Badge {
        return match($this) {
            LocationType::DESK => new Badge('teal', 'chair'),
            LocationType::ROOM => new Badge('indigo', 'shop'),
            LocationType::STORAGE => new Badge('amber', 'lock')
        };
    }
}

enum LocationState: string implements Badged {
    use Enumifier;

    case AVAILABLE = 'AVAILABLE';
    case OCCUPIED = 'OCCUPIED';
    case MAINTENANCE = 'MAINTENANCE';

    public function badge(): Badge {
        return match($this) {
            LocationState::AVAILABLE => new Badge('green', ''),
            LocationState::OCCUPIED => new Badge('red', ''),
            LocationState::MAINTENANCE => new Badge('amber', '')
        };
    }

    public function text(): string {
        return match($this) {
            LocationState::AVAILABLE => 'AVAILABLE',
            LocationState::OCCUPIED => 'OCCUPIED',
            LocationState::MAINTENANCE => 'MAINTENANCE'
        };
    }
}

class Location extends Model
{
    use HasFactory;

    protected $fillable = [
        'title',
        'description',
        'address',
        'latitude',
        'longitude',
        'type',
        'active',
        'image',
        'state',
        'rate_hourly',
        'rate_daily'
    ];

    protected $casts = [
        'active' => 'boolean',
        'type' => LocationType::class,
        'state' => LocationState::class
    ];
}
