<?php

namespace App\Models;

use App\Models\Location;
use App\Models\User;
use App\Traits\Enumifier;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;

use Illuminate\Database\Eloquent\Relations\HasOne;

enum DurationUnit: string {
    use Enumifier;

    case HOUR = 'HOUR';
    case DAY = 'DAY';
}

class Subscription extends Model
{
    use HasFactory;

    protected $fillable = [
        'location_id',
        'user_id',
        'duration',
        'duration_unit',
        'expiry_date',
        'active'
    ];

    protected $casts = [
        'active' => 'boolean',
        'duration_unit' => DurationUnit::class,
        'expiry_date' => 'datetime'
    ];

    public function user (): HasOne {
        return $this->hasOne(User::class, 'id', 'user_id');
    }

    public function location (): HasOne {
        return $this->hasOne(Location::class,'id', 'location_id');
    }
}
