<?php

namespace App\Models;

use App\Interfaces\Badged;
use App\Models\Badge;
use App\Traits\Enumifier;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\HasOne;

enum Mode: string implements Badged {
    use Enumifier;

    case IPAYMU = 'IPAYMU';
    case CREDIT = 'CREDIT';
    case DEBIT = 'DEBIT';
    case EMPLOYEE_CREDIT = 'EMPLOYEE_CREDIT';

    public function badge(): Badge {
        return match($this) {
            Mode::IPAYMU => new Badge('', ''),
            Mode::CREDIT => new Badge('', ''),
            Mode::DEBIT => new Badge('', ''),
            Mode::EMPLOYEE_CREDIT => new Badge('', '')
        };
    }
}

enum TransactionState: string implements Badged {
    use Enumifier;

    case PAID = 'PAID';
    case PENDING = 'PENDING';
    case FAILED = 'FAILED';
    case REFUNDED = 'REFUNDED';

    public function badge(): Badge {
        return match($this) {
            TransactionState::PAID => new Badge('green', ''),
            TransactionState::PENDING => new Badge('blue', ''),
            TransactionState::FAILED => new Badge('red', ''),
            TransactionState::REFUNDED => new Badge('amber', '')
        };
    }
}

class Transaction extends Model
{
    use HasFactory;

    protected $fillable = [
        'subscription_id',
        'state',
        'transaction_code',
        'amount',
        'mode'
    ];

    protected $casts = [
        'complete' => 'boolean',
        'mode' => Mode::class,
        'state' => TransactionState::class
    ];

    public function subscription (): HasOne {
        return $this->hasOne(Subscription::class, 'subscription_id', 'id');
    }
}
