<?php

namespace App\Models;

// use Illuminate\Contracts\Auth\MustVerifyEmail;
use App\Interfaces\Badged;
use App\Models\Badge;
use App\Traits\Enumifier;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Foundation\Auth\User as Authenticatable;
use Illuminate\Notifications\Notifiable;
use Laravel\Sanctum\HasApiTokens;
use Tymon\JWTAuth\Contracts\JWTSubject;


enum UserType: string implements Badged {
    use Enumifier;

    case ADMIN = "ADMIN";
    case STAFF = "STAFF";
    case MEMBER = "MEMBER";

    public function badge(): Badge {
        return match($this) {
            UserType::MEMBER => new Badge('gray', 'money-bills'),
            UserType::STAFF => new Badge('blue', 'helmet-safety'),
            UserType::ADMIN => new Badge('red', 'toolbox')
        };
    }

    public function text(): string {
        return match($this) {
            UserType::MEMBER => 'MEMBER',
            UserType::STAFF => 'STAFF',
            UserType::ADMIN => 'ADMIN'
        };
    }
}

class User extends Authenticatable implements JWTSubject
{
    use HasApiTokens, HasFactory, Notifiable;

    /**
     * The attributes that are mass assignable.
     *
     * @var array<int, string>
     */
    protected $fillable = [
        'name',
        'email',
        'password',
        'phone',
        'type',
        'profile',
        'active'
    ];

    /**
     * The attributes that should be hidden for serialization.
     *
     * @var array<int, string>
     */
    protected $hidden = [
        'password',
        'remember_token',
    ];

    /**
     * The attributes that should be cast.
     *
     * @var array<string, string>
     */
    protected $casts = [
        'email_verified_at' => 'datetime',
        'password' => 'hashed',
        'type' => UserType::class,
        'status' => 'boolean',
        'created_at' => 'datetime'
    ];

    public function getJWTIdentifier() {
        return $this->getKey();
    }

    public function getJWTCustomClaims() {
        return [];
    }
}
