@extends("layouts.app")

@section("title")
{{ $title }}
@stop

@section("head")
    @if(in_array($current, ["invoices", "users", "locations"]))
        <script lang="javascript">
            const toggleSlideover = () => {
                document.getElementById('slideover-container').classList.toggle('invisible');
                document.getElementById('slideover-bg').classList.toggle('opacity-0');
                document.getElementById('slideover-bg').classList.toggle('opacity-50');
                document.getElementById('slideover').classList.toggle('translate-x-full');
            };

            const toggleRateFields = (event) => {
                const type = event.target?.value;
                if (!type) return;

                const hourly = document.querySelector("#hourly");
                if (!hourly) return;

                if (type !== "DESK") {
                    hourly.style.display = "none";
                    hourly.required = false;
                    return;
                }

                hourly.style.display = "block";
                hourly.required = true;
            };
        </script>
    @endif
    <script lang="javascript">
        const search = (page) => {
            const keywords = document.getElementById("keyword")?.value;

            console.log(keywords.trim().length);

            if (keywords.trim().length === 0) {
                location.href = `/${page}`;
                return;
            }

            location.href = `/${page}/search?keyword=${keywords}`;
        };
    </script>
@stop

@if($current == "invoices")
    @section("events")
        <script lang="javascript">
            const dropdownButtonUser = document.getElementById('dropdown-button-user');
            const dropdownMenuUser = document.getElementById('dropdown-menu-user');
            const searchInputUser = document.getElementById('search-input-user');
            let isOpenUser = false; // Set to true to open the dropdown by default

            // Function to toggle the dropdown state
            function toggleDropdownUser() {
                isOpenUser = !isOpenUser;
                dropdownMenuUser.classList.toggle('hidden', !isOpenUser);
            }

            dropdownButtonUser.addEventListener('click', () => {
                toggleDropdownUser();
            });

            // Add event listener to filter items based on input
            searchInputUser.addEventListener('input', () => {
                const searchTerm = searchInputUser.value.toLowerCase();
                const items = dropdownMenuUser.querySelectorAll('a');

                items.forEach((item) => {
                    const text = item.querySelector(".searchable").textContent;
                    if (text.includes(searchTerm)) {
                        item.style.display = 'flex';
                    } else {
                        item.style.display = 'none';
                    }
                });
            });

            const selectUser = (id, name) => {
                dropdownButtonUser.innerText = name;
                document.getElementById('userId').value = id;
                toggleDropdownUser();
            };

            const dropdownButtonLocation = document.getElementById('dropdown-button-location');
            const dropdownMenuLocation = document.getElementById('dropdown-menu-location');
            const searchInputLocation = document.getElementById('search-input-location');
            let isOpenLocation = false; // Set to true to open the dropdown by default

            // Function to toggle the dropdown state
            function toggleDropdownLocation() {
                isOpenLocation = !isOpenLocation;
                dropdownMenuLocation.classList.toggle('hidden', !isOpenLocation);
            }

            dropdownButtonLocation.addEventListener('click', () => {
                toggleDropdownLocation();
            });

            // Add event listener to filter items based on input
            searchInputLocation.addEventListener('input', () => {
                const searchTerm = searchInputLocation.value.toLowerCase();
                const items = dropdownMenuLocation.querySelectorAll('a');

                items.forEach((item) => {
                    const text = item.querySelector(".searchable").textContent.toLowerCase();
                    if (text.includes(searchTerm)) {
                        item.style.display = 'flex';
                    } else {
                        item.style.display = 'none';
                    }
                });
            });

            const selectLocation = (id, name) => {
                dropdownButtonLocation.innerText = name;
                document.getElementById('locationId').value = id;
                toggleDropdownLocation();
            };
        </script>
    @endsection
@endif

@section("body")
<div class="wrapper flex flex-row">
    <aside class="max-h-screen flex-none w-64 shadow-sm">
        <x-sidebar :active="$current" />
    </aside>
    <main class="max-h-screen min-h-screen overflow-auto w-full bg-gray-100">
        <header class="bg-white border-l-2 border-l-gray-100 shadow-md px-7 py-5 flex justify-between items-center">
            <div class="flex items-center space-x-4">
                @if($current != 'home')
                    <label for="keyword" class="mb-2 text-sm font-medium text-gray-900 sr-only">Search</label>
                    <div class="w-96 m-0 relative">
                        <div class="absolute inset-y-0 left-0 text-gray-500 flex items-center pl-3 pointer-events-none">
                            <i class="fa-solid fa-search"></i>
                        </div>
                        <input type="search" id="keyword" name="keyword" class="block w-full p-4 pl-10 text-sm text-gray-900 border border-gray-300 rounded-2xl bg-gray-50 focus:outline-none focus-within:ring-0 focus:ring-0" placeholder="Search Keywords">
                        <button type="button" class="text-white font-bold absolute right-2.5 bottom-2.5 bg-red-400 hover:bg-red-600 focus:ring-4 focus:outline-none focus:ring-red-300 rounded-xl text-sm px-4 py-2" onclick="search('{{ $current }}')">Go</button>
                    </div>
                @endif
            </div>
            <div class="flex items-center space-x-4">
                <div class="relative">
                    @php
                        $authAvatar = Auth::user()->profile;
                    @endphp

                    <button class="flex items-center">
                        <img src="{{ $authAvatar ? asset('avatars/'.$authAvatar) : asset('avatars/profile_placeholder.png') }}" alt="Profile" class="w-10 h-10 rounded-full">
                    </button>

                    <div class="absolute right-0 mt-2 w-48 bg-white border border-gray-300 rounded-md shadow-md hidden">
                        <!-- Profile Dropdown -->
                    </div>
                </div>
            </div>
        </header>
        <div class="wrapper">
            {{ $slot }}
        </div>
    </main>
</div>
@stop
