<x-base title="Invoices" current="invoices">
    @isset($messages)
        <x-messages :messages="$messages" />
    @endisset
    <section class="h-full w-full flex justify-center items-center">
        <div class="w-full px-4">
            <div class="py-4">
                <div class="px-4 py-4 overflow-x-auto">
                    <div class="inline-block min-w-full shadow-md rounded-lg overflow-hidden">
                        <table class="min-w-full leading-normal">
                            <thead>
                                <tr>
                                    <th
                                        class="px-5 py-3 border-b-2 border-gray-200 bg-red-200 text-left text-xs font-semibold text-red-600 uppercase tracking-wider">
                                        User / Phone Number
                                    </th>
                                    <th
                                        class="px-5 py-3 border-b-2 border-gray-200 bg-red-200 text-left text-xs font-semibold text-red-600 uppercase tracking-wider">
                                        Location / Type
                                    </th>
                                    <th
                                        class="px-5 py-3 border-b-2 border-gray-200 bg-red-200 text-left text-xs font-semibold text-red-600 uppercase tracking-wider">
                                        Expires On
                                    </th>
                                    <th
                                        class="px-5 py-3 border-b-2 border-gray-200 bg-red-200 text-left text-xs font-semibold text-red-600 uppercase tracking-wider">
                                        Paid
                                    </th>
                                    <th class="px-5 py-3 border-b-2 border-gray-200 bg-red-200"></th>
                                </tr>
                            </thead>
                            <tbody>
                                @forelse ($invoices as $invoice)
                                    <tr>
                                        <td class="px-5 py-5 border-b border-gray-200 bg-white text-sm">
                                            <p class="font-bold ml-[4px] text-gray-900 whitespace-no-wrap">
                                                {{ $invoice->user->name }}
                                            </p>
                                            <p class="my-1 text-gray-900 whitespace-no-wrap">
                                                <span class="text-[0.8em] font-semibold px-3 py-[6px] rounded-full bg-gray-200 text-gray-600 capitalize">
                                                    <i class="fa-solid fa-phone mr-1"></i>
                                                    <span class="inline-block lowercase first-letter:uppercase">{{ $invoice->user->phone }}</span>
                                                </span>
                                            </p>
                                        </td>
                                        <td class="px-5 py-5 border-b border-gray-200 bg-white text-sm">
                                            @php
                                                $typeBadge = $invoice->subscription->location->type->badge();
                                            @endphp
                                            <p class="my-1 text-gray-900 whitespace-no-wrap">
                                                {{ $invoice->subscription->location->title }}
                                            </p>
                                            <p class="my-1 text-gray-900 whitespace-no-wrap">
                                                <span class="text-[0.8em] font-semibold px-3 py-[6px] rounded-full bg-{{ $typeBadge->color }}-200 text-{{ $typeBadge->color }}-600 capitalize">
                                                    <i class="fa-solid fa-{{ $typeBadge->icon }} mr-1"></i>
                                                    <span class="inline-block lowercase first-letter:uppercase">{{ $invoice->subscription->location->type }}</span>
                                                </span>
                                            </p>
                                        </td>
                                        <td class="px-5 py-5 border-b border-gray-200 bg-white text-sm">
                                            <p class="italic text-gray-900 whitespace-no-wrap">
                                                {{ $invoice->subscription->expiry_date }}
                                            </p>
                                        </td>
                                        <td class="px-5 py-5 border-b border-gray-200 bg-white text-sm">
                                            <label class="relative inline-flex items-center cursor-pointer">
                                                <input type="checkbox" class="sr-only peer" {{ $invoice->paid ? 'checked': '' }} onchange="location.href='/invoices/{{ $invoice->id }}/toggle-paid'">
                                                <div class="w-11 h-6 bg-gray-200 peer-focus:outline-none peer-focus:ring-4 peer-focus:ring-green-300 dark:peer-focus:ring-green-800 rounded-full peer dark:bg-gray-700 peer-checked:after:translate-x-full peer-checked:after:border-white after:content-[''] after:absolute after:top-[2px] after:left-[2px] after:bg-white after:border-gray-300 after:border after:rounded-full after:h-5 after:w-5 after:transition-all dark:border-gray-600 peer-checked:bg-green-600"></div>
                                            </label>
                                        </td>
                                        <td class="px-5 py-5 border-b border-gray-200 bg-white text-right">
                                            <a href="/invoices/{{ $invoice->id }}/delete"
                                                class="mr-4 inline-block text-gray-500 hover:text-gray-700">
                                                <i class="fa-solid fa-trash"></i>
                                            </a>
                                            <a href="/invoices/{{ $invoice->id }}/print"
                                                class="mr-4 inline-block text-gray-500 hover:text-gray-700">
                                                <i class="fa-solid fa-print"></i>
                                            </a>
                                            <a href="/invoices/{{ $invoice->id }}/edit"
                                                class="inline-block text-gray-500 hover:text-gray-700">
                                                <i class="fa-solid fa-pen"></i>
                                            </a>
                                        </td>
                                    </tr>
                                @empty
                                    <tr>
                                        <td colspan="5">
                                            <p class="text-center italic text-gray-400 whitespace-no-wrap p-4 bg-white">
                                                No Results
                                            </p>
                                        </td>
                                    </tr>
                                @endforelse
                            </tbody>
                        </table>
                    </div>
                    <div class="mt-4">
                        {{ $invoices->withQueryString()->links() }}
                    </div>
                </div>
            </div>
        </div>
        @empty($selectedInvoice)
            <x-slideover
                title="Create an invoice"
                subtitle="Please make sure to fill the details correctly before submitting, as the submission are final and immutable.">
                <form class="h-auto m-8 pb-36" method="POST" action="/invoices" enctype="multipart/form-data">
                    @csrf
                    <div class="space-y-12">
                        <div class="border-b border-gray-900/10 pb-12">
                            <div class="mt-10 grid grid-cols-1 gap-x-6 gap-y-8 sm:grid-cols-6">
                                <div class="col-span-full">
                                    <label for="user"
                                        class="block text-sm font-semibold leading-6 text-gray-900">Select a User</label>
                                    <div class="mt-2">
                                        <div class="group">
                                            <input id="userId" type="hidden" name="userId">
                                            <button id="dropdown-button-user" type="button" class="w-full flex items-cenline-flex justify-between p-4 text-gray-700 bg-white border border-gray-300 rounded-2xl focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-offset-gray-100 focus:ring-red-200">
                                                <span class="mr-2">Choose User</span>
                                                <i class="fa-solid fa-chevron-down"></i>
                                            </button>
                                            <div id="dropdown-menu-user" class="hidden absolute w-11/12 max-h-72 overflow-scroll left-8 mt-2 rounded-2xl shadow-lg bg-white ring-1 ring-black ring-opacity-5 p-4 space-y-1">
                                                <input id="search-input-user" class="block w-full p-4 mb-4 text-sm text-gray-800 border rounded-2xl  border-gray-300 focus:outline-none" type="text" placeholder="Search by Phone" autocomplete="off">
                                                @foreach($users as $user)
                                                    <a href="#" onclick="selectUser({{ $user->id }}, '{{ $user->name }}')" class="flex flex-row items-center rounded-2xl p-4 hover:bg-gray-100">
                                                        <img class="w-6 h-6 mr-2 rounded-full" src="{{ $user->profile ? asset('avatars/'.$user->profile) : asset('avatars/profile_placeholder.png') }}" alt="">
                                                        <div class="ml-2 text-sm">
                                                            <label for="helper-radio-4" class="font-medium text-gray-900">
                                                            <div>{{ $user->name }}</div>
                                                            <p class="searchable text-xs font-normal text-gray-500">{{ $user->phone }}</p>
                                                            </label>
                                                        </div>
                                                    </a>
                                                @endforeach
                                            </div>
                                        </div>
                                    </div>
                                </div>

                                <div class="col-span-full">
                                    <label for="user"
                                        class="block text-sm font-semibold leading-6 text-gray-900">Select a Location</label>
                                    <div class="mt-2">
                                        <div class="group">
                                            <input id="locationId" type="hidden" name="locationId">
                                            <button id="dropdown-button-location" type="button" class="w-full flex items-cenline-flex justify-between p-4 text-gray-700 bg-white border border-gray-300 rounded-2xl focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-offset-gray-100 focus:ring-red-200">
                                                <span class="mr-2">Choose Location</span>
                                                <i class="fa-solid fa-chevron-down"></i>
                                            </button>
                                            <div id="dropdown-menu-location" class="hidden z-50 absolute w-11/12 max-h-72 overflow-scroll left-8 mt-2 rounded-2xl shadow-lg bg-white ring-1 ring-black ring-opacity-5 p-4 space-y-1">
                                                <input id="search-input-location" class="block w-full p-4 mb-4 text-sm text-gray-800 border rounded-2xl  border-gray-300 focus:outline-none" type="text" placeholder="Search items" autocomplete="off">
                                                @foreach($locations as $location)
                                                    <a href="#" onclick="selectLocation({{ $location->id }}, '{{ $location->title }}')" class="flex flex-row items-center rounded-2xl p-4 hover:bg-gray-100">
                                                        <img class="w-6 h-6 mr-2 rounded-full" src="{{ $location->image ? asset('products/'.$location->image) : asset('products/location_placeholder.png') }}" alt="">
                                                        <div class="ml-2 text-sm">
                                                            <label for="helper-radio-4" class="font-medium text-gray-900">
                                                            <div class="searchable">{{ $location->title }}</div>
                                                            <p class="text-xs font-normal text-gray-500">{{ $location->longitude }}, {{ $location->latitude }}</p>
                                                            </label>
                                                        </div>
                                                    </a>
                                                @endforeach
                                            </div>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>

                        <div class="border-b border-gray-900/10 pb-12">
                            <h2 class="text-base font-semibold leading-7 text-gray-900">Subscription Details</h2>
                            <p class="mt-1 text-sm leading-6 text-gray-600">Please clearly specify the duration as it affects the overall amount of the invoice.</p>

                            <div class="col-span-full flex flex-row xs:flex-col gap-6 mt-6">
                                <div id="hourly" class="flex-1">
                                    <label for="duration" class="block text-sm font-semibold leading-6 text-gray-900">Duration</label>
                                    <div class="mt-2">
                                        <input type="number" name="duration" id="duration"
                                                class="block w-full rounded-xl p-4 border-0 text-gray-900 shadow-sm ring-1 ring-inset ring-gray-300 placeholder:text-gray-400  focus:outline-none focus:ring-2 focus:ring-inset focus:ring-red-400 sm:text-sm sm:leading-6" placeholder="XX">
                                    </div>
                                </div>
                                <div id="daily" class="flex-1">
                                    <label for="durationUnit" class="block text-sm font-semibold leading-6 text-gray-900">Units</label>
                                    <div class="mt-2">
                                        <select name="durationUnit" id="durationUnit"
                                            class="block w-full bg-white rounded-xl p-5 border-0 text-gray-900 shadow-sm ring-1 ring-inset ring-gray-300 placeholder:text-gray-400  focus:outline-none focus:ring-2 focus:ring-inset focus:ring-red-400 sm:text-sm sm:leading-6">
                                            <option value="HOUR">Hour(s)</option>
                                            <option value="DAY">Day(s)</option>
                                        </select>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>

                    <div class="mt-6 flex items-center justify-start gap-x-6">
                        <button type="submit"
                            class="rounded-xl px-8 py-4 bg-red-400 text-sm font-semibold text-white shadow-sm hover:bg-gray-950 focus-visible:outline focus-visible:outline-2 focus-visible:outline-offset-2 focus-visible:outline-red-400">Save</button>

                        <button type="reset" onclick="toggleSlideover()" class="text-sm font-semibold leading-6 text-gray-900">Cancel</button>
                    </div>
                </form>
            </x-slideover>
            <x-fab />
        @endempty
        @isset($selectedInvoice)
            <x-slideover
                title="Edit invoice"
                subtitle="Please make sure to fill the details correctly before submitting, as the submission are final and immutable.">

            </x-slideover>
        @endisset
    </section>
</x-base>
