@php
    use App\Models\UserType;
@endphp

<x-base title="Users" current="users">
    @isset($messages)
        <x-messages :messages="$messages" />
    @endisset
    <section class="h-full w-full">
        <div class="w-full px-4">
            <div class="py-4">
                <div class="px-4 py-4 overflow-x-auto">
                    <div class="inline-block min-w-full shadow-md rounded-lg overflow-hidden">
                        <table class="min-w-full leading-normal">
                            <thead>
                                <tr>
                                    <th
                                        class="px-5 py-3 border-b-2 border-gray-200 bg-red-200 text-left text-xs font-semibold text-red-600 uppercase tracking-wider">
                                        Name / Phone Number
                                    </th>
                                    <th
                                        class="px-5 py-3 border-b-2 border-gray-200 bg-red-200 text-left text-xs font-semibold text-red-600 uppercase tracking-wider">
                                        Type / Email
                                    </th>
                                    <th
                                        class="px-5 py-3 border-b-2 border-gray-200 bg-red-200 text-left text-xs font-semibold text-red-600 uppercase tracking-wider">
                                        Date Joined
                                    </th>
                                    <th
                                        class="px-5 py-3 border-b-2 border-gray-200 bg-red-200 text-left text-xs font-semibold text-red-600 uppercase tracking-wider">
                                        Active
                                    </th>
                                    <th class="px-5 py-3 border-b-2 border-gray-200 bg-red-200"></th>
                                </tr>
                            </thead>
                            <tbody>
                                @forelse ($users as $user)
                                    <tr>
                                        <td class="px-5 py-5 border-b border-gray-200 bg-white text-sm">
                                            <div class="flex">
                                                <div class="flex-shrink-0 w-10 h-10">
                                                    <img class="w-full h-full rounded-full"
                                                        src="{{ $user->profile ? asset('avatars/'.$user->profile) : asset('avatars/profile_placeholder.png') }}"
                                                        alt="" />
                                                </div>
                                                <div class="ml-3">
                                                    <p class="text-gray-900 whitespace-no-wrap">
                                                        {{ $user->name }}
                                                    </p>
                                                    <p class="text-gray-600 whitespace-no-wrap">{{ $user->phone }}</p>
                                                </div>
                                            </div>
                                        </td>
                                        <td class="px-5 py-5 border-b border-gray-200 bg-white text-sm">
                                            @php
                                                $badge = $user->type->badge();
                                            @endphp
                                            <p class="my-1 text-gray-900 whitespace-no-wrap">
                                                <span class="text-[0.8em] font-semibold px-3 py-[6px] rounded-full bg-{{ $badge->color }}-200 text-{{ $badge->color }}-600 capitalize">
                                                    <i class="fa-solid fa-{{ $badge->icon }} mr-1"></i>
                                                    <span class="inline-block lowercase first-letter:uppercase">{{ $user->type }}</span>
                                                </span>
                                            </p>
                                            <p class="text-[0.8em] ml-[4px] italic text-gray-400 whitespace-no-wrap">
                                                {{ $user->email }}</p>
                                        </td>
                                        <td class="px-5 py-5 border-b border-gray-200 bg-white text-sm">
                                            @php
                                                $interval = $user->created_at->diff(new DateTime('now'));
                                            @endphp
                                            <p class="text-gray-900 whitespace-no-wrap">
                                                {{ date('M d, Y', strtotime($user->created_at)) }}</p>
                                            <p class="text-gray-600 whitespace-no-wrap">{{ $interval->d }} days ago</p>
                                        </td>
                                        <td class="px-5 py-5 border-b border-gray-200 bg-white text-sm">
                                            <label class="relative inline-flex items-center cursor-pointer">
                                                <input type="checkbox" class="sr-only peer" {{ $user->active ? 'checked': '' }} onchange="location.href='/users/{{ $user->id }}/toggle-activation'">
                                                <div class="w-11 h-6 bg-gray-200 peer-focus:outline-none peer-focus:ring-4 peer-focus:ring-green-300 dark:peer-focus:ring-green-800 rounded-full peer dark:bg-gray-700 peer-checked:after:translate-x-full peer-checked:after:border-white after:content-[''] after:absolute after:top-[2px] after:left-[2px] after:bg-white after:border-gray-300 after:border after:rounded-full after:h-5 after:w-5 after:transition-all dark:border-gray-600 peer-checked:bg-green-600"></div>
                                            </label>
                                        </td>
                                        <td class="px-5 py-5 border-b border-gray-200 bg-white text-right">
                                            <a href="/users/{{ $user->id }}/edit"
                                                class="inline-block {{ $user->type->text() == 'ADMIN' ? 'pointer-events-none text-gray-400': 'text-gray-500 hover:text-gray-700' }}">
                                                <i class="fa-solid fa-pen"></i>
                                            </a>
                                        </td>
                                    </tr>
                                @empty
                                <tr>
                                    <td colspan="5">
                                        <p class="text-center italic text-gray-400 whitespace-no-wrap p-4 bg-white">
                                            No Results
                                        </p>
                                    </td>
                                </tr>
                                @endforelse
                            </tbody>
                        </table>
                    </div>
                    <div class="mt-4">
                        {{ $users->withQueryString()->links() }}
                    </div>
                </div>
            </div>
        </div>
        @empty($selectedUser)
            <x-slideover title="Add Admin User" subtitle="Please make sure to choose the type carefully as this affects which system resources the person gets access to.">
                <form class="h-auto m-8 pb-36" action="/users" method="POST" enctype="multipart/form-data">
                    @csrf
                    <div class="space-y-12">
                        <div class="border-b border-gray-900/10 pb-12">
                            <div class="mt-10 grid grid-cols-1 gap-x-6 gap-y-8 sm:grid-cols-6">
                                <div class="sm:col-span-full">
                                    <label for="title"
                                        class="block text-sm font-semibold leading-6 text-gray-900">Name</label>
                                    <div class="mt-2">
                                        <input type="text" id="name"
                                            class="block w-full rounded-xl p-4 border-0 text-gray-900 shadow-sm ring-1 ring-inset ring-gray-300 placeholder:text-gray-400  focus:outline-none focus:ring-2 focus:ring-inset focus:ring-red-400 sm:text-sm sm:leading-6">
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>

                    <div class="mt-6 flex items-center justify-start gap-x-6">
                        <button type="submit"
                            class="rounded-xl px-8 py-4 bg-red-400 text-sm font-semibold text-white shadow-sm hover:bg-gray-950 focus-visible:outline focus-visible:outline-2 focus-visible:outline-offset-2 focus-visible:outline-red-400">Update</button>

                        <button type="button" onclick="location.href='/users'" class="text-sm font-semibold leading-6 text-gray-900">Cancel</button>
                    </div>
                </form>
            </x-slideover>
            <x-fab />
        @endempty
        @isset($selectedUser)
            <x-slideover title="Edit User" :fixed="true" closeAction="location.href='/users'"
                subtitle="Please make sure to choose the type carefully as this affects which system resources the person gets access to.">
                <form class="h-auto m-8 pb-36" action="/users/{{ $selectedUser->id }}/update" method="POST">
                    @csrf
                    @method('PUT')
                    <div class="space-y-12">
                        <div class="border-b border-gray-900/10 pb-12">
                            <div class="mt-10 grid grid-cols-1 gap-x-6 gap-y-8 sm:grid-cols-6">
                                <div class="sm:col-span-full">
                                    <label for="title"
                                        class="block text-sm font-semibold leading-6 text-gray-900">Name</label>
                                    <div class="mt-2">
                                        <input type="text" id="name" value="{{ $selectedUser->name }}"
                                            class="block w-full rounded-xl p-4 border-0 text-gray-900 shadow-sm ring-1 ring-inset ring-gray-300 placeholder:text-gray-400  focus:outline-none focus:ring-2 focus:ring-inset focus:ring-red-400 sm:text-sm sm:leading-6"
                                            disabled readonly>
                                    </div>
                                </div>

                                <div class="sm:col-span-3">
                                    <label for="type" class="block text-sm font-semibold leading-6 text-gray-900">Membership Type</label>
                                    <div class="mt-2">
                                        <select id="type" name="type"
                                            class="block w-full rounded-xl p-4 border-0 text-gray-900 shadow-sm ring-1 ring-inset ring-gray-300  focus:outline-none focus:ring-2 focus:ring-inset focus:ring-red-400 sm:max-w-xs sm:text-sm sm:leading-6"
                                            onchange="toggleRateFields(event)"
                                            required>
                                            <option value="MEMBER" {{ $selectedUser->type->text() == "MEMBER" ? 'selected': '' }}>Member</option>
                                            <option value="STAFF" {{ $selectedUser->type->text() == "STAFF" ? 'selected': '' }}>Staff</option>
                                            <option value="ADMIN" {{ $selectedUser->type->text() == "ADMIN" ? 'selected': '' }}>Admin</option>
                                        </select>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>

                    <div class="mt-6 flex items-center justify-start gap-x-6">
                        <button type="submit"
                            class="rounded-xl px-8 py-4 bg-red-400 text-sm font-semibold text-white shadow-sm hover:bg-gray-950 focus-visible:outline focus-visible:outline-2 focus-visible:outline-offset-2 focus-visible:outline-red-400">Update</button>

                        <button type="button" onclick="location.href='/users'" class="text-sm font-semibold leading-6 text-gray-900">Cancel</button>
                    </div>
                </form>
            </x-slideover>
        @endisset
    </section>
</x-base>
