<?php

use App\Http\Controllers\InvoiceController;
use App\Http\Controllers\LocationController;
use App\Http\Controllers\LoginController;
use App\Http\Controllers\TransactionController;
use App\Http\Controllers\UserController;
use Illuminate\Support\Facades\Route;

/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider and all of them will
| be assigned to the "web" middleware group. Make something great!
|
*/

Route::get('/', function () {
    // Dummy data for home
    $stats = array(
        [
            'title' => 'Total Users',
            'value' => '101',
            'color' => 'blue',
            'icon' => 'user-group'
        ],
        [
            'title' => 'Outstanding Invoices',
            'value' => '190',
            'color' => 'indigo',
            'icon' => 'money-bill'
        ],
        [
            'title' => 'Total Locations',
            'value' => '350',
            'color' => 'amber',
            'icon' => 'user-group'
        ],
        [
            'title' => 'Occupation Rate',
            'value' => '24.57%',
            'color' => 'green',
            'icon' => 'lock-open'
        ]
    );

    return view('pages.home', ['stats' => $stats]);
})->middleware('auth:web')->name('home');

Route::prefix('invoices')->group(function () {
    Route::controller(InvoiceController::class)->group(function () {
        Route::get('/', 'index')->middleware('auth:web')->name('invoices');
        Route::post('/', 'store')->middleware('auth:web');
        Route::get('/search', 'search')->middleware('auth:web');
        Route::get('/{invoiceId}/edit','edit')->middleware('auth:web');
        Route::get('/{invoiceId}/toggle-paid', 'togglePaid')->middleware('auth:web');
    });
});

Route::prefix('locations')->group(function () {
    Route::controller(LocationController::class)->group(function () {
        Route::get('/', 'index')->middleware('auth:web')->name('locations');
        Route::post('/', 'store')->middleware('auth:web');
        Route::get('/search', 'search')->middleware('auth:web');
        Route::get('/{locationId}/edit', 'edit')->middleware('auth:web');
        Route::put('/{locationId}/update', 'update')->middleware('auth:web');
        Route::get('/{locationId}/toggle-activation', 'toggleActivation')->middleware('auth:web');
    });
});

Route::prefix('users')->group(function () {
    Route::controller(UserController::class)->group(function () {
        Route::get('/', 'index')->middleware('auth:web')->name('users');
        Route::get('/search', 'search')->middleware('auth:web');
        Route::get('/{userId}/edit', 'edit')->middleware('auth:web');
        Route::put('/{userId}/update', 'update')->middleware('auth:web');
        Route::get('/{userId}/toggle-activation', 'toggleActivation')->middleware('auth:web');
    });
});

Route::prefix('transactions')->group(function () {
    Route::controller(TransactionController::class)->group(function () {
        Route::get('/', 'index')->middleware('auth:web');
    });
});

Route::controller(LoginController::class)->group(function () {
    Route::get('/login', 'index')->name('login');
    Route::get('/logout', 'logout')->name('logout');
    Route::post('/login', 'authenticate')->name('authenticate');
});
